@@ -20,7 +20,8 @@ class ConsumerManager():
                          'value.deserializer': avro_deserializer,
                          'group.id': self.options.consumer_group,
                          'message.max.bytes': self.options.message_max_bytes,
-                         'auto.offset.reset': self.options.offset_type}
+                         'auto.offset.reset': self.options.offset_type,
+                         'max.poll.interval.ms': self.options.max_poll_interval}
 
         self.consumer = DeserializingConsumer(consumer_conf)
         self.consumer.subscribe([kafka_topic])
